#!/usr/bin/perl

# Subroutines are critical for keeping code organized and understandable
# They allow tasks to be defined once and separated from the main body of
# the code so that the main structure of the program remains clear.
# In this example the common task of rounding a number to a certain number
# of decimal places is put in a subroutine.

print round(152.6752,100);
# the subroutine call contains two arguments: 152.6752 and 100
# these arguments are passed to the subroutine

# round (152.6752,100) returns 152.68 (rounds x at the y decimal position)

sub round {

my $number = $_[0];
my $decimal = $_[1];
# arguments that are passed to the subroutine are available as follows:
# $_[0] is the first argument, $_[1] is the second, and so on.
# By placing "my" in front of the variable it makes the variable "local"
# This means that this variable only has this value WITHIN the subroutine
# For example, if you are outside the subroutine the $number variable will
# not keep the value you have assigned it in the subroutine, but may either
# be undefined, or have a value that was assigned to it globally.
# To assign a value to a variable regardless of where you are in the program
# (a global variable) simply do not use "my" in front of the variable assignment.

return (int($number * $decimal +0.5))/$decimal;
# the return function sends a value back to the place where the subroutine was called

} # end of the round subroutine

# Some things to remember
# 1. Subroutines can call other subroutines
# 2. Subroutines don't need to return anything